@@ -306,7 +306,16 @@ class Browser(contextlib.AbstractContextManager):
     def open(self) -> BrowserContext:
         """Start the browser"""
         self.driver = self.driver()  # XXX: Don't make Browsers one-time
-        self.driver.get(self.url)
+        tries = 42  # Arbitrary number of tries
+        while tries > 0:
+            try:
+                self.driver.get(self.url)
+                break
+            except selenium_exceptions.WebDriverException:
+                tries -= 1
+                continue
+        if tries == 0:
+            raise RuntimeError("Could not load URL")
         return BrowserContext(self.url, self.driver)
 
     def close(self) -> None:
